@@ -10,8 +10,8 @@ class RuleSetAdmin(admin.ModelAdmin):
     list_display = (
         'enabled',
         'uri_regex',
+        'user_filter_type',
         'user_group_filter',
-        'include_anonymous',
     )
 
 admin.site.register(
@@ -28,7 +28,8 @@ class ProfilingRecordAdmin(admin.ModelAdmin):
         'duration',
         'request_uri',
         'view_func_name',
-        'response_status_code'
+        'response_status_code',
+        'response_content_length'
     )
 
 admin.site.register(
